@@ -33,7 +33,7 @@ use Perl6::Export::Attrs;
 use Encode qw(decode_utf8);
 use utf8;
 
-our $VERSION = '2.3.11';
+our $VERSION = '2.3.12';
 
 my $q = new CGI;
 
@@ -341,38 +341,21 @@ __END__
 
 =head1 NAME
 
-FamilyTreeInfo - Family Tree Generator
+Ftree - Family Tree Generator, genealogical program on Perl
 
-=for HTML 
-<a href="https://travis-ci.org/mishin/POD-to-RU"><img src="https://camo.githubusercontent.com/4d5013ccad85146ce9c975dce7d677e20a632b5a/68747470733a2f2f7472617669732d63692e6f72672f6d697368696e2f504f442d746f2d52552e7376673f6272616e63683d6d6173746572" alt="Build Status" data-canonical-src="https://travis-ci.org/mishin/POD-to-RU.svg?branch=master" style="max-width:100%;"></a>
-<a href="https://coveralls.io/r/mishin/POD-to-RU?branch=master"><img src="https://camo.githubusercontent.com/8769056c0371af38c8fd59b06de30c14037c8f33/68747470733a2f2f636f766572616c6c732e696f2f7265706f732f6d697368696e2f504f442d746f2d52552f62616467652e706e673f6272616e63683d6d6173746572" alt="Coverage Status" data-canonical-src="https://coveralls.io/repos/mishin/POD-to-RU/badge.png?branch=master" style="max-width:100%;"></a>
-<a href="http://cpants.charsbar.org/dist/overview/POD2-RU"><img src="https://camo.githubusercontent.com/fbfe24c64a9d7662a1b9fb774ead7f7fe34fec71/687474703a2f2f6370616e74732e6370616e617574686f72732e6f72672f646973742f504f44322d52552e706e67" alt="Kwalitee status" data-canonical-src="http://cpants.cpanauthors.org/dist/POD2-RU.png" style="max-width:100%;"></a>
-<a href="https://github.com/mishin/POD-to-RU/issues"><img src="https://camo.githubusercontent.com/adb231d4b9884b6955a2f9373ce099654193182a/68747470733a2f2f696d672e736869656c64732e696f2f6769746875622f6973737565732f6d697368696e2f504f442d746f2d52552e737667" alt="GitHub issues" data-canonical-src="https://img.shields.io/github/issues/mishin/POD-to-RU.svg" style="max-width:100%;"></a>
-<a href="https://metacpan.org/release/POD2-RU"><img src="https://camo.githubusercontent.com/f176cd20b10c2aa1639142f327302a7b9fbc21b2/68747470733a2f2f696d672e736869656c64732e696f2f6370616e2f6c2f504f44322d52552e737667" alt="Cpan license" data-canonical-src="https://img.shields.io/cpan/l/POD2-RU.svg" style="max-width:100%;"></a>
-<a href="https://metacpan.org/release/POD2-RU"><img src="https://camo.githubusercontent.com/df363da200ccfd0741da030dd26b99a2612c8fff/68747470733a2f2f696d672e736869656c64732e696f2f6370616e2f762f504f44322d52552e737667" alt="Cpan version" data-canonical-src="https://img.shields.io/cpan/v/POD2-RU.svg" style="max-width:100%;"></a></p>
+=head1 PACKAGE CONTENTS:
 
-=head1 NAME
+  readme.txt                     This file
+  config/PerlSettingsImporter.pm Settings file
+  cgi/ftree.cgi                  The main perl script
+  cgi/*.pm                       Other perl modules
+  tree.txt, tree.xls, royal.ged  Example family tree data files
+  license.txt                    The GNU GPL license details
+  changes.txt					   Change history
+  pictures/*.[gif,png,jpg,tif]   The pictures of the relatives
+  graphics/*.gif                 The system graphic files 
 
-Ftree - Genealogical program on Perl
-
-=head1 SYNOPSIS
-
-  About the Family Tree Generator, v2.3.*
-
-
-PACKAGE CONTENTS:
-
-readme.txt                     This file
-config/PerlSettingsImporter.pm Settings file
-cgi/ftree.cgi                  The main perl script
-cgi/*.pm                       Other perl modules
-tree.txt, tree.xls, royal.ged  Example family tree data files
-license.txt                    The GNU GPL license details
-changes.txt					   Change history
-pictures/*.[gif,png,jpg,tif]   The pictures of the relatives
-graphics/*.gif                 The system graphic files 
-
-OVERVIEW:
+=head1 OVERVIEW:
  
 When I designed the Family Tree Generator, I wanted more than just an online version of a traditional tree. With this software it is possible to draw a tree of ancestors and descendants for any person, showing any number of generations (where the information exists).
 Most other web-based "trees" are little more than text listings of people. 
@@ -388,7 +371,7 @@ It runs as a CGI program - its output is the HTML of the page that you see.
 The program reads in the data file, and analyzes the relationships to determine the ancestors, siblings and descendants of the person selected. 
 HTML tables are generated to display these trees, linking in the portrait images where they exist.
 
-INSTALLATION INSTRUCTIONS:
+=head1 INSTALLATION INSTRUCTIONS:
 
 1. Set up your web server (apache or IIS) so that it can run Perl scripts (e.g. mod-perl).
 
@@ -406,236 +389,170 @@ INSTALLATION INSTRUCTIONS:
 
 7. If you are unhappy with the style and colors of the output then point the css_filename entry in PerlSettingsImporter.pm into your stly sheet.
 
-DATAFILE FORMAT:
+=head1 INSTALLATION INSTRUCTIONS FOR XAMPP for Windows 5.6.12:
 
-The program can handle excel, csv (txt), gedcom, serialized files and can get data from database. Follow these rules to decide which one to use:
-1, Use gedcom if you already have your family tree data in a gedcom file and the fields that the program is able to import is sufficient.
-2, Use the excel format if you just started to build your family tree data.
-3, Convert your data file into serialized format if the data file contains many people (like some thousand) and you would like to reduce response time and memory need.
-
-Data format history:
-Originally the input file was a csv flat file with semicolon as the separator. It could store 6 fields for each person (name, father name, mother name, email, webpage, date of birth/death). As new fields were required (like gender, place of birth, cemetery, etc.) and the number of optional fields increased from 5 to 22, the csv format turned out to be hard to maintain. Although it is possible to be imported/exported into excel, it would be better to use excel spreadsheets directly. From version 2.2 this is possible. For backward compatibility it is still possible to use csv files. The new fields can be used in csv fields as well. From version 2.3 gedcom files can also be used.
-
-We encourage everybody to use the excel format. To convert from the csv format to the excel format, use script script/convertFormat.pl
-
-TIP 1.: Maintain your family tree data in excel using the Form option. Select all the columns, then press DATA->Form. It is convenient to add new people or to modify information of existing persons.
-TIP 2.: Freeze the first line so that header does not disappear when scrolling down. 
-
-The excel format:
-
-The excel format is quite straightforward based on the example file. Each row (except the header) represents a person. The fields are:
- * ID: the ID of the person. It can be anything (like 123 or Bart_Simpson), but it should only contain alphanumeric characters and underscore (no whitespace is allowed).
- * title: like: Dr., Prof.
- * prefix: like: sir
- * first name
- * middle name 
- * last Name
- * suffix: like: VIII
- * nickname
- * father's ID
- * mother's ID
- * email
- * webpage
- * date of birth: the format is day/month/year, like: 24/3/1977
- * date of death: the format is day/month/year, like: 24/3/1977
- * gender: 0 for male, 1 female
- * is living?: 0 for live 1 for dead
- * place of birth: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
- * place of death: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
- * cemetery: the format is: "country" "city" "cemetery", like: "USA" "Washington D.C." "Arlington National Cemetery"
- * schools: use comma as separator, like: Harward, MIT
- * jobs: use comma as separator
- * work places: use comma as separator
- * places of living: places separated by comma, like: "USA" "Springfield", "USA" "Connecticut"
- * general: you would typically write something general about the person.
-Note, that the extension of an excel data file must be xls.
-
-Tip: Select the second row, click on menu Window and select Freeze Panels.
-This will freeze the first row and you can see the title of columns.
-
-The csv format:
-Semicolon is the separator. The fields are:
-
-1. Full name.
-   Middle names can be included in this field.
-   If more than one person share the same name, a number can be appended (not shown in the displayed output). For example, "Bart Simpson2". 
-2. Father (optional - leave blank if not known). No middle names. 
-3. Mother (optional) 
-4. email address (optional) 
-5. web page (optional) 
-6. Dates, birth-death (both optional).
-   Examples: "17/10/49-24/11/83", "10/69-"
-   Note that the year of birth is not displayed for people who are still alive. 
-7. Gender (0 for male, 1 for female)
-8. title: like: Dr., Prof.
-9. prefix: like: sir
-10. suffix: like: VIII
-11. is living?: 0 for live 1 for dead
-12. place of birth: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
-13. place of death: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
-14. cemetery: the format is: "country" "city" "cemetery", like: "USA" "Washington D.C." "Arlington National Cemetery"
-15. schools: use comma as separator, like: Harward,MIT
-16. jobs: use comma as separator
-17. work places: use comma as separator
-18. places of living: places separated by comma, like: "USA" "Springfield", "USA" "Connecticut"
-19. general: you would typically write something general about the person.
-Note, that the extension of a csv data file must be either csv or txt. To define the encoding of the file use option encoding in the config file.
-
-Convert from csv (txt) format to excel format:
-To switch from comma separated value file to excel spreadsheet, do the following:
-cd ftree2
-perl ./scripts/convertFormat.pl ./tree.txt ./tree.xls
-This will generate (overwrite) a tree.xls file. 
-
-The GEDCOM format:
-GEDCOM, an acronym for GEnealogical Data COMmunication, is a specification for exchanging genealogical data between different genealogy software. GEDCOM was developed by The Church of Jesus Christ of Latter-day Saints as an aid in their extensive genealogical research. A GEDCOM file is plain text (an obscure text encoding named ANSEL, though often in ASCII in the United States) containing genealogical information about individuals, and data linking these records together. Most genealogy software supports importing from and/or exporting to GEDCOM format.
-
-Beside the father, mother relationships, the program handles the following information of a person:
-1, gender
-2, date of birth
-3, date of death
-4, place of birth (only city and country are extracted)
-5, place of death (only city and country are extracted)
-6, cemetery (only cemetery, city and country are extracted)
-7, email address
-8, homepage
-
-It is possible to switch from GEDCOM to excel (or serialized) format. Use the scripts/convertFormat.pl script. For example
-cd ftree2
-perl ./scripts/convertFormat.pl ./tree.ged ./tree.xls
-
-The ser format:
-The drawback of excel, csv and GEDCOM format is that it has to be parsed and processed every time the program runs. It is possible to speed-up the program (and hence reduce response time) and reduce memory usage if you use the serialized format. The serialized format cannot be edited directly. Basically you maintain your family tree data in excel (or in csv or GEDCOM) then create a serialized file using scripts/convertFormat.pl program. If the name of the family tree data is ftree.xls then, the following commands will generate the serialized file:
-
-cd ftree2
-perl ./scripts/convertFormat.pl ./tree.xls ./tree.ser
-
-Don't forget to set the data_source to "../tree.ser" in the PerlSettingsImporter.pm file.
-
-Note, that the extension of a serialized data file must be ser. Also keep in mind that different versions of perl may produce incompatible serialized versions. It is advised to run the convertFormat.pl script on the same mashine where the webserver runs.
-
-NAME OF THE PICTURE:
-
-One picture may belong to each person. The name of the picture file reflects the person it belongs to. The picture file is obtained from the lowercased full name by substituting spaces with underscores and adding the file extension to it. From example from "Ferenc Bodon3" we get "ferenc_bodon3.jpg".
-
-PERFORMANCE ISSUES:
-This sofware was not designed so that it can handle very large family trees. It can easily cope with few thousands of members, but latency (time till page is generated) grows as the size of the family tree increases.
-The main bottleneck of performance is that (1.) mod_perl is not used, therefore perl interpreter is starts for every request (2.) family tree is not cached but data file is parsed and tree is built-up for every request (using serialized format helps a little).
-Since the purpose of this software is to provide a free and simple tool for those who would like to maintain their family tree themself, performance is not the primary concern.
-
-SECURITY ISSUES:
-The protection provided by password request (set in config file) is quite primitive, i.e. it is easy to break it.
-Ther are historical reasons for being available. We suggest to use server side protection like .htaccess files in case of apache web servers. 
-
-Hi Ferenc Bodon
-========================
+Download I use xampp XAMPP for Windows 5.6.12 (https://www.apachefriends.org/ru/download.html) to install and configure Apache  
  
-I install your program ftree:  
-
-1. I copy it to github: https://github.com/mishin/ftree  
-------------------------
-
-2. I use xampp XAMPP for Windows 5.6.12 (https://www.apachefriends.org/ru/download.html) to install and configure Apache  
-------------------------
-I could not install mod_perl on Ubuntu 14.14 (because of Unable to locate package libapache2-mod-perl2 - bad old repository issue!!)
- 
-<IfModule alias_module>  
-  
-#  
-# ScriptAlias /cgi-bin/ "C:/xampp/cgi-bin/"  
-ScriptAlias /cgi-bin/ "C:/xampp/cgi-bin/ftree/cgi/"  
-  
-</IfModule>  
-  
-<Directory "C:/xampp/cgi-bin/ftree/cgi">  
-AllowOverride All  
-Options None  
-Require all granted  
-</Directory>  
+  <IfModule alias_module>  
+  ScriptAlias /cgi-bin/ "C:/xampp/cgi-bin/ftree/cgi/"  
+  </IfModule>  
   
+  <Directory "C:/xampp/cgi-bin/ftree/cgi">  
+  AllowOverride All  
+  Options None  
+  Require all granted  
+  </Directory>  
    
-3. My shebang in ftree.cgi is #!"c:\Dwimperl\perl\bin\perl.exe" (by Gabor Sabo)  
-------------------------
-4. I remover included package Params::Validate  
-------------------------
-because of error  Undefined subroutine Params::Validate::SCALAR perl  
-and install new one (1.21)  
+My shebang in ftree.cgi is #!"c:\Dwimperl\perl\bin\perl.exe" (by Gabor Sabo)  
  
-5. Also I copy
-------------------------
-c:\xampp\cgi-bin\ftree\graphics\  
-  
-to  
-  
-c:\xampp\htdocs\graphics\  
+  copy c:\xampp\cgi-bin\ftree\graphics\   
+  to    
+  c:\xampp\htdocs\graphics\  
   
 to correct show images  
   
-6. I catch error couldn't create child process: 720002
+I catch error couldn't create child process: 720002
 ------------------------
-Because   
-If found it !  
 It was the first line in the .cgi file that needed to be adapted to Xamp's configuration:  
   
-#!"c:\xampp\perl\bin\perl.exe"  
-Instead of:  
+  #!"c:\xampp\perl\bin\perl.exe"  
+  Instead of:  
   
-#!"c:\perl\bin\perl.exe"  
+  #!"c:\perl\bin\perl.exe"  
   
 https://forum.xojo.com/20697-couldn-t-create-child-process-720002-error-when-deploying-on-wi/0  
 http://open-server.ru/forum/viewtopic.php?f=6&t=1059  
   
-7. Image cancatenate
-------------------------
-NAME OF THE PICTURE:
+=head1 NAME OF THE PICTURE:
   
-One picture may belong to each person. The name of the picture file reflects the person it belongs to. The picture file is   obtained from the lowercased full name by substituting spaces with underscores and adding the file extension to it. From   example from "Ferenc Bodon3" we get "ferenc_bodon3.jpg". 
+  One picture may belong to each person. 
+  No image put here and name=id.jpg
+  c:\xampp\cgi-bin\ftree\pictures\  
 
-No image put here and name=id.jpg
-c:\xampp\cgi-bin\ftree\pictures\  
+=head1 DATAFILE FORMAT:
 
+  The program can handle excel, csv (txt), gedcom, serialized files and can get data from database. Follow these rules to decide which one to use:
+  1, Use gedcom if you already have your family tree data in a gedcom file and the fields that the program is able to import is sufficient.
+  2, Use the excel format if you just started to build your family tree data.
+  3, Convert your data file into serialized format if the data file contains many people (like some thousand) and you would like to reduce response time and memory need.
 
-  
-So, It's a good work,  
+  Data format history:
+  Originally the input file was a csv flat file with semicolon as the separator. It could store 6 fields for each person (name, father name, mother name, email, webpage, date of birth/death). As new fields were required (like gender, place of birth, cemetery, etc.) and the number of optional fields increased from 5 to 22, the csv format turned out to be hard to maintain. Although it is possible to be imported/exported into excel, it would be better to use excel spreadsheets directly. From version 2.2 this is possible. For backward compatibility it is still possible to use csv files. The new fields can be used in csv fields as well. From version 2.3 gedcom files can also be used.
 
-1. but I prefer some refectoring, move to PSGI  
-2. Also, very good if it will be like DWIM  
-when you can install it simply click to exe file  
-without any others moving.  
- 
-I'm ready to help with it  
- 
-Best regards  
-Nikolay Mishin  
+  We encourage everybody to use the excel format. To convert from the csv format to the excel format, use script script/convertFormat.pl
 
+  TIP 1.: Maintain your family tree data in excel using the Form option. Select all the columns, then press DATA->Form. It is convenient to add new people or to modify information of existing persons.
+  TIP 2.: Freeze the first line so that header does not disappear when scrolling down. 
 
-generate cpanfile  
+=head1 The excel format:
 
-c:\xampp\cgi-bin\ftree\cgi\lib>perl c:\Users\TOSH\Documents\GitHub\App-scan_prereqs_cpanfile\script\scan-prereqs-cpanfile --ignore=version
+  The excel format is quite straightforward based on the example file. Each row (except the header) represents a person. The fields are:
+   * ID: the ID of the person. It can be anything (like 123 or Bart_Simpson), but it should only contain alphanumeric characters and underscore (no whitespace is allowed).
+   * title: like: Dr., Prof.
+   * prefix: like: sir
+   * first name
+   * middle name 
+   * last Name
+   * suffix: like: VIII
+   * nickname
+   * father's ID
+   * mother's ID
+   * email
+   * webpage
+   * date of birth: the format is day/month/year, like: 24/3/1977
+   * date of death: the format is day/month/year, like: 24/3/1977
+   * gender: 0 for male, 1 female
+   * is living?: 0 for live 1 for dead
+   * place of birth: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
+   * place of death: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
+   * cemetery: the format is: "country" "city" "cemetery", like: "USA" "Washington D.C." "Arlington National Cemetery"
+   * schools: use comma as separator, like: Harward, MIT
+   * jobs: use comma as separator
+   * work places: use comma as separator
+   * places of living: places separated by comma, like: "USA" "Springfield", "USA" "Connecticut"
+   * general: you would typically write something general about the person.
+  Note, that the extension of an excel data file must be xls.
 
+  Tip: Select the second row, click on menu Window and select Freeze Panels.
+  This will freeze the first row and you can see the title of columns.
 
+=head1 The csv format:
 
-=head1 VERSION
+  Semicolon is the separator. The fields are:
 
-This document describes cpanfile format version 1.0.
+  1. Full name.
+   Middle names can be included in this field.
+   If more than one person share the same name, a number can be appended (not shown in the displayed output). For example, "Bart Simpson2". 
+  2. Father (optional - leave blank if not known). No middle names. 
+  3. Mother (optional) 
+  4. email address (optional) 
+  5. web page (optional) 
+  6. Dates, birth-death (both optional).
+  Examples: "17/10/49-24/11/83", "10/69-"
+   Note that the year of birth is not displayed for people who are still alive. 
+  7. Gender (0 for male, 1 for female)
+  8. title: like: Dr., Prof.
+  9. prefix: like: sir
+  10. suffix: like: VIII
+  11. is living?: 0 for live 1 for dead
+  12. place of birth: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
+  13. place of death: the format is: "country" "city". The city part may be omitted. Quotation marks are mandatory.
+  14. cemetery: the format is: "country" "city" "cemetery", like: "USA" "Washington D.C." "Arlington National Cemetery"
+  15. schools: use comma as separator, like: Harward,MIT
+  16. jobs: use comma as separator
+  17. work places: use comma as separator
+  18. places of living: places separated by comma, like: "USA" "Springfield", "USA" "Connecticut"
+  19. general: you would typically write something general about the person.
+  Note, that the extension of a csv data file must be either csv or txt. To define the encoding of the file use option encoding in the config file.
 
-=head1 DESCRIPTION  
+=head1 Convert from csv (txt) format to excel format:
 
+  To switch from comma separated value file to excel spreadsheet, do the following:
+  cd ftree2
+  perl ./scripts/convertFormat.pl ./tree.txt ./tree.xls
+  This will generate (overwrite) a tree.xls file. 
 
-=head1 SYNTAX
+  The GEDCOM format:
+  GEDCOM, an acronym for GEnealogical Data COMmunication, is a specification for exchanging genealogical data between different genealogy software. GEDCOM was developed by The Church of Jesus Christ of Latter-day Saints as an aid in their extensive genealogical research. A GEDCOM file is plain text (an obscure text encoding named ANSEL, though often in ASCII in the United States) containing genealogical information about individuals, and data linking these records together. Most genealogy software supports importing from and/or exporting to GEDCOM format.
 
-=over 4
+  Beside the father, mother relationships, the program handles the following information of a person:
+  1, gender
+  2, date of birth
+  3, date of death
+  4, place of birth (only city and country are extracted)
+  5, place of death (only city and country are extracted)
+  6, cemetery (only cemetery, city and country are extracted)
+  7, email address
+  8, homepage
 
-=item requires, recommends, suggests, conflicts
+  It is possible to switch from GEDCOM to excel (or serialized) format. Use the scripts/convertFormat.pl script. For example
+  cd ftree2
+  perl ./scripts/convertFormat.pl ./tree.ged ./tree.xls
 
+The ser format:
+  The drawback of excel, csv and GEDCOM format is that it has to be parsed and processed every time the program runs. It is possible to speed-up the program (and hence reduce response time) and reduce memory usage if you use the serialized format. The serialized format cannot be edited directly. Basically you maintain your family tree data in excel (or in csv or GEDCOM) then create a serialized file using scripts/convertFormat.pl program. If the name of the family tree data is ftree.xls then, the following commands will generate the serialized file:
 
-=back
+  cd ftree2
+  perl ./scripts/convertFormat.pl ./tree.xls ./tree.ser
 
-=head1 USAGE
+  Don't forget to set the data_source to "../tree.ser" in the PerlSettingsImporter.pm file.
 
-C<cpanfile> is a format to describe dependencies. How to use this file
-is dependent on the tools reading/writing it.
+  Note, that the extension of a serialized data file must be ser. Also keep in mind that different versions of perl may produce incompatible serialized versions. It is advised to run the convertFormat.pl script on the same mashine where the webserver runs.
 
+=head1 NAME OF THE PICTURE:
+
+One picture may belong to each person. The name of the picture file reflects the person it belongs to. The picture file is obtained from the lowercased full name by substituting spaces with underscores and adding the file extension to it. From example from "Ferenc Bodon3" we get "ferenc_bodon3.jpg".
+
+=head1 PERFORMANCE ISSUES:
+
+This sofware was not designed so that it can handle very large family trees. It can easily cope with few thousands of members, but latency (time till page is generated) grows as the size of the family tree increases.
+The main bottleneck of performance is that (1.) mod_perl is not used, therefore perl interpreter is starts for every request (2.) family tree is not cached but data file is parsed and tree is built-up for every request (using serialized format helps a little).
+Since the purpose of this software is to provide a free and simple tool for those who would like to maintain their family tree themself, performance is not the primary concern.
+
+=head1 SECURITY ISSUES:
+
+The protection provided by password request (set in config file) is quite primitive, i.e. it is easy to break it.
+Ther are historical reasons for being available. We suggest to use server side protection like .htaccess files in case of apache web servers. 
 
 =head1 AUTHORS
 
@@ -643,7 +560,8 @@ Dr. Ferenc Bodon and Simon Ward
 http://www.cs.bme.hu/~bodon/en/index.html
 http://simonward.com
 
-Maintainer
+=head1 MAINTAINER
+
 Nikolay Mishin
 
 =head1 COPYRIGHT
